function foldsIndices = createFolds(inputFile, numberOfFolds)

% foldsIndex = createFolds(inputFile, numberOfFolds)
%
% Input Variables
%       inputFile - A mat file containing a two dimensional cell array. The
%                   first cell is a text label for the second cell. The second 
%                   cell is a time series. The variable in the mat file must be called
%                   "timeSeries"
%       numberOfFolds - the number of folds to make
%
% Output Variable
%       foldsIndices - A cell array of dimension equal to numberOfFolds with
%                      the elements in each cell being the indexes into the
%                      timeseries.
%
% Language - MATLAB
%  
% Description:  Forms statistically balanced (across classes) folds
%
% Created:     
%               Date: 6/19/2003  
%               By:  Richard J. Povinelli
%               Marquette University
%
% Modified:    
%               Version:
%               Date: 
%               By: 
%               Why: 

data = load(inputFile,'-mat'); %loads in the workspace, which must contain a timeSeries variable
allLabels = data.timeSeries(:,1); %copies the labels out of data
clear data;
uniqueLabels = unique(allLabels); %find the unique class labels
numberOfClasses = length(uniqueLabels); %find the number of classes

%form a cell array structure with each class being an index and all example signals belong to that class
foldsIndices = cell(numberOfFolds,1);
foldIndex = 1;
for i = 1:numberOfClasses
  classIndices = strmatch(uniqueLabels(i),allLabels,'exact'); %get indices for each class
  classIndices = randomizeArray(classIndices); %randomize the indices
  elementsInClass = length(classIndices);
  
  %put a each element in a fold
  for j = 1:elementsInClass
    foldsIndices{foldIndex} = [foldsIndices{foldIndex} classIndices(j)];
    foldIndex = mod(foldIndex, numberOfFolds) + 1; %wrap around if needed and increment
  end %for
end %for

return
